NapiCodeFrameOptions

Struct NapiCodeFrameOptions 

pub struct NapiCodeFrameOptions {
    pub lines_above: Option<u32>,
    pub lines_below: Option<u32>,
    pub max_width: Option<u32>,
    pub color: Option<bool>,
    pub highlight_code: Option<bool>,
    pub message: Option<String>,
    pub language: Option<String>,
}

Fields

lines_above: Option<u32>

Number of lines to show above the error (default: 2)

lines_below: Option<u32>

Number of lines to show below the error (default: 3)

max_width: Option<u32>

Maximum width of the output in columns (default: 100)

color: Option<bool>

Whether to use ANSI colors (default: false)

highlight_code: Option<bool>

Whether to highlight code syntax (default: follows color)

This might be useful if syntax highlighting is very expensive or known to be useless for this file. The current syntax rules are optimized for javascript but should work well with other C-like languages.

message: Option<String>

Optional message to display with the code frame

language: Option<String>

Language hint for keyword highlighting: “javascript” (default) or “css”