git_version_info

Function git_version_info 

pub fn git_version_info(describe: &str) -> GitVersionInfo<'_>
Returns version info derived from the supplied Next.js version and compile-time git metadata.

The dirty flag is only set when not running in CI (CI env var unset at build time) and the working tree was dirty at build time.