get_issues

Function get_issues 

pub async fn get_issues<T: Send>(
    source: OperationVc<T>,
    filter: &IssueFilter,
) -> Result<Arc<Vec<ReadRef<PlainIssue>>>>
Peeks at the Issues held by the given source and returns them as PlainIssues. It does not consume any Issues held by the source.