pub async fn get_issues<T: Send>(
source: OperationVc<T>,
filter: &IssueFilter,
) -> Result<Arc<Vec<ReadRef<PlainIssue>>>>Expand description
Peeks at the Issues held by the given source and returns them as PlainIssues.
It does not consume any Issues held by the source.